summaryrefslogtreecommitdiffstats
path: root/knights/tabmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knights/tabmanager.cpp')
-rw-r--r--knights/tabmanager.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/knights/tabmanager.cpp b/knights/tabmanager.cpp
index f2d72fc..efd4899 100644
--- a/knights/tabmanager.cpp
+++ b/knights/tabmanager.cpp
@@ -19,9 +19,9 @@
#include "resource.h"
#include <kdebug.h>
-static QString myConfigGroup( "TabManager" );
+static TQString myConfigGroup( "TabManager" );
-TabManager::TabManager( resource *rsrc ) : QObject()
+TabManager::TabManager( resource *rsrc ) : TQObject()
{
myResource = rsrc;
appConfig = kapp->config();
@@ -36,7 +36,7 @@ TabManager::~TabManager()
// TabManager::addTab
//
///////////////////////////////////////
-void TabManager::addTab( QWidget *child, const QString &caption )
+void TabManager::addTab( TQWidget *child, const TQString &caption )
{
TabBox *boxPtr;
@@ -49,8 +49,8 @@ void TabManager::addTab( QWidget *child, const QString &caption )
/* Get Geometry from Saved Config */
appConfig->setGroup( myConfigGroup );
- QSize defaultSize( 420, 360 );
- QSize newSize = appConfig->readSizeEntry( QString( child->className() ), &defaultSize );
+ TQSize defaultSize( 420, 360 );
+ TQSize newSize = appConfig->readSizeEntry( TQString( child->className() ), &defaultSize );
boxPtr->resize( newSize );
boxPtr->show();
}
@@ -65,7 +65,7 @@ void TabManager::addTab( QWidget *child, const QString &caption )
// TabManager::changeCaption
//
///////////////////////////////////////
-void TabManager::changeCaption( QWidget *child, const QString &caption )
+void TabManager::changeCaption( TQWidget *child, const TQString &caption )
{
TabBox *boxPtr = getParentBox( child );
@@ -79,30 +79,30 @@ void TabManager::changeCaption( QWidget *child, const QString &caption )
// TabManager::removeTab
//
///////////////////////////////////////
-void TabManager::removeTab( QObject *child )
+void TabManager::removeTab( TQObject *child )
{
/* Make sure this is a QWidget we can manipulate */
if( !child->isWidgetType() )
{
kdError() << "TabManager::removeTab: Can not remove non-widget class " << child->className() << endl;
return;
}
- if( myList.find( ((TabBox*)child) ) != -1 )
+ if( myList.tqfind( ((TabBox*)child) ) != -1 )
{
/* Remove Child Directly */
myList.remove( ((TabBox*)child) );
return;
}
- QString childName( ((QWidget*)child)->className() );
- TabBox *boxPtr = getParentBox( ((QWidget*)child) );
+ TQString childName( ((TQWidget*)child)->className() );
+ TabBox *boxPtr = getParentBox( ((TQWidget*)child) );
/* Remove this Child's Parent, the TabPage */
if( boxPtr != NULL )
{
kdDebug() << "Removing child: " << childName << endl;
- boxPtr->removeTab( ((QWidget*)child), TRUE );
+ boxPtr->removeTab( ((TQWidget*)child), TRUE );
if( boxPtr->count() == 0 )
{
myList.remove( boxPtr );
@@ -117,7 +117,7 @@ void TabManager::removeTab( QObject *child )
// TabManager::showTab
//
///////////////////////////////////////
-void TabManager::showTab( QWidget *child )
+void TabManager::showTab( TQWidget *child )
{
TabBox *boxPtr = getParentBox( child );
if( boxPtr != NULL )
@@ -130,7 +130,7 @@ void TabManager::showTab( QWidget *child )
// TabManager::isTab
//
///////////////////////////////////////
-bool TabManager::isTab( QWidget *child )
+bool TabManager::isTab( TQWidget *child )
{
if( getParentBox( child ) == NULL )
{
@@ -143,31 +143,31 @@ bool TabManager::isTab( QWidget *child )
// TabManager::saveTabGeometry
//
///////////////////////////////////////
-void TabManager::saveTabGeometry( const QString &childName, const QSize &childSize )
+void TabManager::saveTabGeometry( const TQString &childName, const TQSize &childSize )
{
/* Save This Widget's Size For Later */
appConfig->setGroup( myConfigGroup );
appConfig->writeEntry( childName, childSize );
appConfig->sync();
- kdDebug() << "Saved geometry for Widget: " << childName << endl;
+ kdDebug() << "Saved tqgeometry for Widget: " << childName << endl;
}
///////////////////////////////////////
//
// TabManager::childEvent
//
///////////////////////////////////////
-void TabManager::childEvent( QChildEvent *event )
+void TabManager::childEvent( TQChildEvent *event )
{
if( event->inserted() )
{
/* New Child */
- if( QString( event->child()->className() ) == "TabBox" )
+ if( TQString( TQT_TQOBJECT(event->child())->className() ) == "TabBox" )
{
manageNewBox( ((TabBox*)event->child()) );
return;
}
- addTab( ((QWidget*)event->child()), QString( "Untitled" ) );
+ addTab( ((TQWidget*)event->child()), TQString( "Untitled" ) );
}
}
///////////////////////////////////////
@@ -178,16 +178,16 @@ void TabManager::childEvent( QChildEvent *event )
void TabManager::manageNewBox( TabBox *newBox )
{
myList.append( newBox );
- connect( newBox, SIGNAL( destroyed( QObject* ) ), this, SLOT( removeTab( QObject* ) ) );
- connect( newBox, SIGNAL( saveTabGeometry( const QString&, const QSize& ) ), this, SLOT( saveTabGeometry( const QString&, const QSize& ) ) );
- connect( newBox, SIGNAL( newTabBox( TabBox* ) ), this, SLOT( manageNewBox( TabBox* ) ) );
+ connect( newBox, TQT_SIGNAL( destroyed( TQObject* ) ), this, TQT_SLOT( removeTab( TQObject* ) ) );
+ connect( newBox, TQT_SIGNAL( saveTabGeometry( const TQString&, const TQSize& ) ), this, TQT_SLOT( saveTabGeometry( const TQString&, const TQSize& ) ) );
+ connect( newBox, TQT_SIGNAL( newTabBox( TabBox* ) ), this, TQT_SLOT( manageNewBox( TabBox* ) ) );
}
///////////////////////////////////////
//
// TabManager::getParentBox
//
///////////////////////////////////////
-TabBox* TabManager::getParentBox( QWidget *child )
+TabBox* TabManager::getParentBox( TQWidget *child )
{
TabBox *boxPtr;
for( unsigned int index=0; index < myList.count(); index++ )
@@ -79,30 +79,30 @@ void TabManager::changeCaption( QWidget *child, const QString &caption )
{
- /* Make sure this is a QWidget we can manipulate */
+ /* Make sure this is a TQWidget we can manipulate */
if( !child->isWidgetType() )
{